pub enum FamilyNameSyntax {
Quoted,
Identifiers(String),
}Variants
Quoted
The family name was specified in a quoted form, e.g. “Font Name” or ‘Font Name’.
Identifiers(String)
The family name was specified in an unquoted form as a sequence of identifiers.
The String is the serialization of the sequence of identifiers.