pub enum FontWeight {
_100,
_200,
_300,
_400,
_500,
_600,
_700,
_800,
_900,
}Expand description
A font-weight value for a @font-face rule. The font-weight CSS property specifies the weight or boldness of the font.
Variants
Implementations
Sourceimpl FontWeight
impl FontWeight
pub const normal: FontWeight = FontWeight::_400
pub const bold: FontWeight = FontWeight::_700
Sourcepub fn from_int(weight: i32) -> Result<Self, ()>
pub fn from_int(weight: i32) -> Result<Self, ()>
Convert from an integer to Weight As of CSS Fonts Module Level 3, only the following values are valid: 100, 200, 300, 400, 500, 600, 700, 800 and 900
pub fn isExactlyNormal(&self) -> bool
pub fn isExactlyBold(&self) -> bool
pub fn isBold(&self) -> bool