Module keyframes

Module keyframes 

Structs

Keyframe
A keyframe.
KeyframePercentage
A percentage from 0% to 100%, indicating the percentage of the animation when this keyframe should run.
KeyframeSelector
A keyframes selector is a list of percentages or from/to symbols, which are converted at parse time to percentages.
KeyframesAtRule
A @keyframes rule. Keyframes: https://drafts.csswg.org/css-animations/#keyframes

Enums

KeyframesName
https://drafts.csswg.org/css-animations/#typedef-keyframes-name