Module properties

Module properties 

Structs

DoesNotHaveImportance
A type representing that !important can not be present in a property declaration
PropertyDeclaration
PropertyDeclarations
A list of property declarations
SpecifiedValue
A specified value for a property is just a set of tokens.

Enums

CssWideKeyword
An enum to represent a CSS-wide keyword.
Importance
A declaration importance.
UnparsedPropertyValue

Traits

HasImportance
A trait representing that !important can or can not be present in a property declaration