pub enum StylesheetError {
Io(PathBuf, Error),
Format(PathBuf, Error),
Parse(PathBuf, SourceLocation, String),
}Expand description
Represents all the things that can go wrong when loading and saving stylesheets.
Variants
Io(PathBuf, Error)
An input-output error occurred, typically when loading or creating a file.
Format(PathBuf, Error)
An error occurred during a std::fmt::write (only happens when saving).
Parse(PathBuf, SourceLocation, String)
An error occurred during a parse.