Contains definitions of objects used in Stylesheet.
Modules
Structs
- Atom
- NOTE: At some future point, Atom may become a wrapper around a string cache value
- CssRules
- A list of CSS rules.
- Custom
Ident - https://drafts.csswg.org/css-values-4/#custom-idents
- Specified
Url - A specified url() value; should be resolved relative to the stylesheet containing it
- Style
Rule - A style rule, with selectors and declarations.
Enums
- Counter
Style Ident - CssRule
- No Charset here, CSSCharsetRule has been removed from CSSOM (https://drafts.csswg.org/cssom/#changes-from-5-december-2013) and Edge doesn’t support it
- CssRule
Type - Rules
Mutate Error - Vendor
Prefix - Vendor prefixes Sort order is such that -o- sorts before -webkit- and -ms- sorts after -webkit-, but -epub- (which is only supported by Webkit) sorts before -webkit- There ae other, now rare prefixes, such as -vx- (for Opera before -o-), -wap- (for WAP; a very defunct standard from 1999), -khtml- (for Webkit’s predecessor) and so on. However, there are hardly ever encountered and so aren’t explicitly coded for.