pub struct FontFeatureValuesAtRule {
pub family_names: Vec<FamilyName>,
pub swash: Vec<FontFeatureValuesDeclaration<SingleValue>>,
pub stylistic: Vec<FontFeatureValuesDeclaration<SingleValue>>,
pub ornaments: Vec<FontFeatureValuesDeclaration<SingleValue>>,
pub annotation: Vec<FontFeatureValuesDeclaration<SingleValue>>,
pub character_variant: Vec<FontFeatureValuesDeclaration<PairValues>>,
pub styleset: Vec<FontFeatureValuesDeclaration<VectorValues>>,
}Expand description
The @font-feature-values at-rule.
Fields
family_names: Vec<FamilyName>Font family list for @font-feature-values rule. Family names cannot contain generic families. FamilyName also accepts only non-generic names.
swash: Vec<FontFeatureValuesDeclaration<SingleValue>>A @swash block. Specifies a feature name that will work with the swash() functional notation of font-variant-alternates.
stylistic: Vec<FontFeatureValuesDeclaration<SingleValue>>A @stylistic block. Specifies a feature name that will work with the annotation() functional notation of font-variant-alternates.
ornaments: Vec<FontFeatureValuesDeclaration<SingleValue>>A @ornaments block. Specifies a feature name that will work with the ornaments() ] functional notation of font-variant-alternates.
annotation: Vec<FontFeatureValuesDeclaration<SingleValue>>A @annotation block. Specifies a feature name that will work with the stylistic() functional notation of font-variant-alternates.
character_variant: Vec<FontFeatureValuesDeclaration<PairValues>>A @character-variant block. Specifies a feature name that will work with the styleset() functional notation of font-variant-alternates. The value can be a pair.
styleset: Vec<FontFeatureValuesDeclaration<VectorValues>>A @styleset block. Specifies a feature name that will work with the character-variant() functional notation of font-variant-alternates. The value can be a list.
Implementations