Structs
- Keyframe
- A keyframe.
- Keyframe
Percentage - A percentage from 0% to 100%, indicating the percentage of the animation when this keyframe should run.
- Keyframe
Selector - A keyframes selector is a list of percentages or from/to symbols, which are converted at parse time to percentages.
- Keyframes
AtRule - A
@keyframesrule. Keyframes: https://drafts.csswg.org/css-animations/#keyframes