Structs
- Does
NotHave Importance - A type representing that !important can not be present in a property declaration
- Property
Declaration - Property
Declarations - A list of property declarations
- Specified
Value - A specified value for a property is just a set of tokens.
Enums
- CssWide
Keyword - An enum to represent a CSS-wide keyword.
- Importance
- A declaration importance.
- Unparsed
Property Value
Traits
- HasImportance
- A trait representing that !important can or can not be present in a property declaration